==> mingw-w64-onefetch-2.19.0-1.src.tar.zst: onefetch-2.19.0/ascii/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### New Features

 - <csr-id-5cc8ea62b8a7e467554ee7b20bb1e85fa36d4979/> parse multi-byte unicode chars correctly + docs
   * fix: parse multi-byte unicode chars correctly
* tests(ascii): add unicode block assertation to render
* docs(ascii): add AsciiArt usage example
* docs(ascii): fix ascii doc onefetch link
* docs(ascii): add badges to readme
* docs(ascii): add no_run to example

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 17 commits contributed to the release over the course of 180 calendar days.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 3 unique issues were worked on: [#934](https://github.com/o2sh/onefetch/issues/934), [#936](https://github.com/o2sh/onefetch/issues/936), [#992](https://github.com/o2sh/onefetch/issues/992)

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **[#934](https://github.com/o2sh/onefetch/issues/934)**
    - Turn `AsciiArt.rs` into its own crate ([`1716519`](https://github.com/o2sh/onefetch/commit/17165192bf187fbd56298a53e34373d8329bfa3a))
 * **[#936](https://github.com/o2sh/onefetch/issues/936)**
    - Parse multi-byte unicode chars correctly + docs ([`5cc8ea6`](https://github.com/o2sh/onefetch/commit/5cc8ea62b8a7e467554ee7b20bb1e85fa36d4979))
 * **[#992](https://github.com/o2sh/onefetch/issues/992)**
    - Fix typo ([`fa80f33`](https://github.com/o2sh/onefetch/commit/fa80f3308ff6f19a3c62233ecbc9767ffa7b9ac9))
 * **Uncategorized**
    - Bump version ([`dccd5a8`](https://github.com/o2sh/onefetch/commit/dccd5a8ccf51f10fb6e38af6b16735b3cac5b315))
    - Cargo changelog --write ([`7eb48ae`](https://github.com/o2sh/onefetch/commit/7eb48ae5c1ef2727a2bb070556aca21506667629))
    - Bump version ([`9cc5e52`](https://github.com/o2sh/onefetch/commit/9cc5e5295bfd678ae157a3fbcd8019ae6f7759e0))
    - Cargo clippy pedantic ([`ca1db57`](https://github.com/o2sh/onefetch/commit/ca1db57fd3e60656dd83993dc0a7ba6e8f0a6469))
    - Cargo changelog --write ([`83197c9`](https://github.com/o2sh/onefetch/commit/83197c9fa2f7ee36fe86af05743431921bdff68e))
    - Bump version ([`e42360d`](https://github.com/o2sh/onefetch/commit/e42360d1569cfab87d2f4d11a8c42e3401bd699f))
    - Cargo changelog --write ([`3d6d600`](https://github.com/o2sh/onefetch/commit/3d6d6001f1120508165e8ec6c1fad3660e316718))
    - Bump version ([`ae536d3`](https://github.com/o2sh/onefetch/commit/ae536d39edaaf55b395f32cea0a3b1b9586a1f15))
    - Merge branch 'main' of github.com:o2sh/onefetch ([`e57965a`](https://github.com/o2sh/onefetch/commit/e57965a82e2c11a9b0108db52d37d288dc6de5cd))
    - Cargo changelog --write ([`df0d5e8`](https://github.com/o2sh/onefetch/commit/df0d5e8af774b4c0676a94b81fed88dc10215f51))
    - Bump version ([`ca05166`](https://github.com/o2sh/onefetch/commit/ca05166f22910410f71615e6599e522e3885e64a))
    - Cargo clippy ([`0959021`](https://github.com/o2sh/onefetch/commit/095902190d4d6adf4548e203ffe3f5c680c08cd6))
    - Bump version ([`a39623a`](https://github.com/o2sh/onefetch/commit/a39623aee24e8f166cb4cc93aea051bd331dffc7))
    - Bump version ([`0a7fc67`](https://github.com/o2sh/onefetch/commit/0a7fc67bee24a9bfc7367ae6fdaee5bb336852c4))
</details>

==> mingw-w64-onefetch-2.20.0-2.src.tar.zst: onefetch-2.20.0/ascii/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### New Features

 - <csr-id-5cc8ea62b8a7e467554ee7b20bb1e85fa36d4979/> parse multi-byte unicode chars correctly + docs
   * fix: parse multi-byte unicode chars correctly
* tests(ascii): add unicode block assertation to render
* docs(ascii): add AsciiArt usage example
* docs(ascii): fix ascii doc onefetch link
* docs(ascii): add badges to readme
* docs(ascii): add no_run to example

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 19 commits contributed to the release over the course of 314 calendar days.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 4 unique issues were worked on: [#1142](https://github.com/o2sh/onefetch/issues/1142), [#934](https://github.com/o2sh/onefetch/issues/934), [#936](https://github.com/o2sh/onefetch/issues/936), [#992](https://github.com/o2sh/onefetch/issues/992)

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **[#1142](https://github.com/o2sh/onefetch/issues/1142)**
    - Use workspace inheritance ([`83462df`](https://github.com/o2sh/onefetch/commit/83462df56b32082caf5718cd1665346765c6ee32))
 * **[#934](https://github.com/o2sh/onefetch/issues/934)**
    - Turn `AsciiArt.rs` into its own crate ([`1716519`](https://github.com/o2sh/onefetch/commit/17165192bf187fbd56298a53e34373d8329bfa3a))
 * **[#936](https://github.com/o2sh/onefetch/issues/936)**
    - Parse multi-byte unicode chars correctly + docs ([`5cc8ea6`](https://github.com/o2sh/onefetch/commit/5cc8ea62b8a7e467554ee7b20bb1e85fa36d4979))
 * **[#992](https://github.com/o2sh/onefetch/issues/992)**
    - Fix typo ([`fa80f33`](https://github.com/o2sh/onefetch/commit/fa80f3308ff6f19a3c62233ecbc9767ffa7b9ac9))
 * **Uncategorized**
    - Cargo changelog --write ([`871f98a`](https://github.com/o2sh/onefetch/commit/871f98a6b99e8ac28445951c545c7c32ca722079))
    - Bump version ([`dccd5a8`](https://github.com/o2sh/onefetch/commit/dccd5a8ccf51f10fb6e38af6b16735b3cac5b315))
    - Cargo changelog --write ([`7eb48ae`](https://github.com/o2sh/onefetch/commit/7eb48ae5c1ef2727a2bb070556aca21506667629))
    - Bump version ([`9cc5e52`](https://github.com/o2sh/onefetch/commit/9cc5e5295bfd678ae157a3fbcd8019ae6f7759e0))
    - Cargo clippy pedantic ([`ca1db57`](https://github.com/o2sh/onefetch/commit/ca1db57fd3e60656dd83993dc0a7ba6e8f0a6469))
    - Cargo changelog --write ([`83197c9`](https://github.com/o2sh/onefetch/commit/83197c9fa2f7ee36fe86af05743431921bdff68e))
    - Bump version ([`e42360d`](https://github.com/o2sh/onefetch/commit/e42360d1569cfab87d2f4d11a8c42e3401bd699f))
    - Cargo changelog --write ([`3d6d600`](https://github.com/o2sh/onefetch/commit/3d6d6001f1120508165e8ec6c1fad3660e316718))
    - Bump version ([`ae536d3`](https://github.com/o2sh/onefetch/commit/ae536d39edaaf55b395f32cea0a3b1b9586a1f15))
    - Merge branch 'main' of github.com:o2sh/onefetch ([`e57965a`](https://github.com/o2sh/onefetch/commit/e57965a82e2c11a9b0108db52d37d288dc6de5cd))
    - Cargo changelog --write ([`df0d5e8`](https://github.com/o2sh/onefetch/commit/df0d5e8af774b4c0676a94b81fed88dc10215f51))
    - Bump version ([`ca05166`](https://github.com/o2sh/onefetch/commit/ca05166f22910410f71615e6599e522e3885e64a))
    - Cargo clippy ([`0959021`](https://github.com/o2sh/onefetch/commit/095902190d4d6adf4548e203ffe3f5c680c08cd6))
    - Bump version ([`a39623a`](https://github.com/o2sh/onefetch/commit/a39623aee24e8f166cb4cc93aea051bd331dffc7))
    - Bump version ([`0a7fc67`](https://github.com/o2sh/onefetch/commit/0a7fc67bee24a9bfc7367ae6fdaee5bb336852c4))
</details>
